@@ -17,11 +17,14 @@ class EnterpriseReportingModelManager(models.Manager):
     Custom ModelManager for every model that wants to use `enterprise_reporting` database.
     """
 
-    def db_manager(self, using=None, hints=None):  # pylint: disable=unused-argument
+    def get_queryset(self):
         """
         Override to use the `enterprise_reporting` database instead of default.
         """
-        return super().db_manager(using=settings.ENTERPRISE_REPORTING_DB_ALIAS, hints=hints)
+        qs = super().get_queryset()
+        qs = qs.using(settings.ENTERPRISE_REPORTING_DB_ALIAS)
+
+        return qs
 
 
 class EnterpriseLearner(models.Model):
